==> org.opennms.features.events.api-20.0.0-20170203.193251-70-sources.jar: org/opennms/netmgt/events/api/EventIpcBroadcaster.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2002-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.events.api;

import org.opennms.netmgt.xml.event.Event;

/**
 * Back-end interface for the EventIpcManager.  Used by eventd to send events
 * to interested listeners.
 */
public interface EventIpcBroadcaster {
    /**
     * Called by eventd to send an event to all interested listeners.
     *
     * @param event a {@link org.opennms.netmgt.xml.event.Event} object.
     */
    void broadcastNow(Event event);
}

==> org.opennms.features.events.api-25.0.0-20190426.233308-45-sources.jar: org/opennms/netmgt/events/api/EventIpcBroadcaster.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2002-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.events.api;

import org.opennms.netmgt.xml.event.Event;

/**
 * Back-end interface for the EventIpcManager.  Used by eventd to send events
 * to interested listeners.
 */
public interface EventIpcBroadcaster {
    /**
     * Called by eventd to send an event to all interested listeners.
     *
     * @param event a {@link org.opennms.netmgt.xml.event.Event} object.
     * @param synchronous Whether this call should wait for all {@link EventListener}
     *   calls to finish before returning.
     */
    void broadcastNow(Event event, boolean synchronous);
}
